Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(592)

Unified Diff: third_party/WebKit/Source/core/layout/compositing/CompositedLayerMapping.cpp

Issue 1407383005: Fix flattening for scrollable areas. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase. Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/compositing/CompositedLayerMapping.cpp
diff --git a/third_party/WebKit/Source/core/layout/compositing/CompositedLayerMapping.cpp b/third_party/WebKit/Source/core/layout/compositing/CompositedLayerMapping.cpp
index 11a622a87ac5e2e2a0dcb4902dd6308cdf5ae439..5a38b9ab974ac9936100501fc2aeb538eb86621e 100644
--- a/third_party/WebKit/Source/core/layout/compositing/CompositedLayerMapping.cpp
+++ b/third_party/WebKit/Source/core/layout/compositing/CompositedLayerMapping.cpp
@@ -1511,12 +1511,13 @@ void CompositedLayerMapping::updateShouldFlattenTransform()
}, ApplyToChildContainingLayers);
}
// Regardless, mark the scrolling contents layer and scrolling block
// selection layer (if they exist) as not flattening. Having them flatten
// causes unclipped render surfaces which cause bugs.
// http://crbug.com/521768
if (hasScrollingLayer()) {
- m_scrollingContentsLayer->setShouldFlattenTransform(false);
+ m_graphicsLayer->setShouldFlattenTransform(false);
+ m_scrollingLayer->setShouldFlattenTransform(false);
if (m_scrollingBlockSelectionLayer)
m_scrollingBlockSelectionLayer->setShouldFlattenTransform(false);
}
@@ -1511,12 +1511,13 @@ void CompositedLayerMapping::updateShouldFlattenTransform()
}, ApplyToChildContainingLayers);
}
- // Regardless, mark the scrolling contents layer and scrolling block
+ // Regardless, mark the graphics layer, scrolling layer and scrolling block
// selection layer (if they exist) as not flattening. Having them flatten
// causes unclipped render surfaces which cause bugs.

Powered by Google App Engine
This is Rietveld 408576698